@@ -39,7 +39,7 @@ impl FlairPart {
 						Self {
 							flair_part_type: value("e").to_string(),
 							value: match value("e") {
-								"text" => value("t").to_string(),
+								"text" => esc!(value("t")),
 								"emoji" => format_url(value("u")),
 								_ => String::new(),
 							},
@@ -52,7 +52,7 @@ impl FlairPart {
 			"text" => match text_flair {
 				Some(text) => vec![Self {
 					flair_part_type: "text".to_string(),
-					value: text.to_string(),
+					value: esc!(text),
 				}],
 				None => Vec::new(),
 			},
@@ -217,12 +217,12 @@ pub struct Post {
 
 impl Post {
 	// Fetch posts of a user or subreddit and return a vector of posts and the "after" value
-	pub async fn fetch(path: &str, fallback_title: String) -> Result<(Vec<Self>, String), String> {
+	pub async fn fetch(path: &str, fallback_title: String, quarantine: bool) -> Result<(Vec<Self>, String), String> {
 		let res;
 		let post_list;
 
 		// Send a request to the url
-		match json(path.to_string()).await {
+		match json(path.to_string(), quarantine).await {
 			// If success, receive JSON in response
 			Ok(response) => {
 				res = response;
@@ -253,7 +253,7 @@ impl Post {
 
 			posts.push(Self {
 				id: val(post, "id"),
-				title: esc!(if title.is_empty() { fallback_title.to_owned() } else { title }),
+				title: esc!(if title.is_empty() { fallback_title.clone() } else { title }),
 				community: val(post, "subreddit"),
 				body: rewrite_urls(&val(post, "body_html")),
 				author: Author {
@@ -362,7 +362,7 @@ pub struct Subreddit {
 	pub title: String,
 	pub description: String,
 	pub info: String,
-	pub moderators: Vec<String>,
+	// pub moderators: Vec<String>,
 	pub icon: String,
 	pub members: (String, String),
 	pub active: (String, String),
@@ -416,11 +416,16 @@ impl Preferences {
 //
 
 // Grab a query parameter from a url
-pub fn param(path: &str, value: &str) -> String {
-	match Url::parse(format!("https://libredd.it/{}", path).as_str()) {
-		Ok(url) => url.query_pairs().into_owned().collect::<HashMap<_, _>>().get(value).unwrap_or(&String::new()).to_owned(),
-		_ => String::new(),
-	}
+pub fn param(path: &str, value: &str) -> Option<String> {
+	Some(
+		Url::parse(format!("https://libredd.it/{}", path).as_str())
+			.ok()?
+			.query_pairs()
+			.into_owned()
+			.collect::<HashMap<_, _>>()
+			.get(value)?
+			.clone(),
+	)
 }
 
 // Retrieve the value of a setting by name
@@ -443,7 +448,7 @@ pub fn setting(req: &Request<Body>, name: &str) -> String {
 // Detect and redirect in the event of a random subreddit
 pub async fn catch_random(sub: &str, additional: &str) -> Result<Response<Body>, String> {
 	if (sub == "random" || sub == "randnsfw") && !sub.contains('+') {
-		let new_sub = json(format!("/r/{}/about.json?raw_json=1", sub)).await?["data"]["display_name"]
+		let new_sub = json(format!("/r/{}/about.json?raw_json=1", sub), false).await?["data"]["display_name"]
 			.as_str()
 			.unwrap_or_default()
 			.to_string();
@@ -458,83 +463,71 @@ pub fn format_url(url: &str) -> String {
 	if url.is_empty() || url == "self" || url == "default" || url == "nsfw" || url == "spoiler" {
 		String::new()
 	} else {
-		match Url::parse(url) {
-			Ok(parsed) => {
-				let domain = parsed.domain().unwrap_or_default();
+		Url::parse(url).map_or(String::new(), |parsed| {
+			let domain = parsed.domain().unwrap_or_default();
 
-				let capture = |regex: &str, format: &str, segments: i16| {
-					Regex::new(regex)
-						.map(|re| match re.captures(url) {
-							Some(caps) => match segments {
-								1 => [format, &caps[1]].join(""),
-								2 => [format, &caps[1], "/", &caps[2]].join(""),
-								_ => String::new(),
-							},
-							None => String::new(),
-						})
-						.unwrap_or_default()
+			let capture = |regex: &str, format: &str, segments: i16| {
+				Regex::new(regex).map_or(String::new(), |re| {
+					re.captures(url).map_or(String::new(), |caps| match segments {
+						1 => [format, &caps[1]].join(""),
+						2 => [format, &caps[1], "/", &caps[2]].join(""),
+						_ => String::new(),
+					})
+				})
+			};
+
+			macro_rules! chain {
+				() => {
+					{
+						String::new()
+					}
 				};
 
-				macro_rules! chain {
-					() => {
-						{
-							String::new()
+				( $first_fn:expr, $($other_fns:expr), *) => {
+					{
+						let result = $first_fn;
+						if result.is_empty() {
+							chain!($($other_fns,)*)
 						}
-					};
-
-					( $first_fn:expr, $($other_fns:expr), *) => {
+						else
 						{
-							let result = $first_fn;
-							if result.is_empty() {
-								chain!($($other_fns,)*)
-							}
-							else
-							{
-								result
-							}
+							result
 						}
-					};
-				}
-
-				match domain {
-					"v.redd.it" => chain!(
-						capture(r"https://v\.redd\.it/(.*)/DASH_([0-9]{2,4}(\.mp4|$))", "/vid/", 2),
-						capture(r"https://v\.redd\.it/(.+)/(HLSPlaylist\.m3u8.*)$", "/hls/", 2)
-					),
-					"i.redd.it" => capture(r"https://i\.redd\.it/(.*)", "/img/", 1),
-					"a.thumbs.redditmedia.com" => capture(r"https://a\.thumbs\.redditmedia\.com/(.*)", "/thumb/a/", 1),
-					"b.thumbs.redditmedia.com" => capture(r"https://b\.thumbs\.redditmedia\.com/(.*)", "/thumb/b/", 1),
-					"emoji.redditmedia.com" => capture(r"https://emoji\.redditmedia\.com/(.*)/(.*)", "/emoji/", 2),
-					"preview.redd.it" => capture(r"https://preview\.redd\.it/(.*)", "/preview/pre/", 1),
-					"external-preview.redd.it" => capture(r"https://external\-preview\.redd\.it/(.*)", "/preview/external-pre/", 1),
-					"styles.redditmedia.com" => capture(r"https://styles\.redditmedia\.com/(.*)", "/style/", 1),
-					"www.redditstatic.com" => capture(r"https://www\.redditstatic\.com/(.*)", "/static/", 1),
-					_ => String::new(),
-				}
+					}
+				};
 			}
-			Err(_) => String::new(),
-		}
+
+			match domain {
+				"v.redd.it" => chain!(
+					capture(r"https://v\.redd\.it/(.*)/DASH_([0-9]{2,4}(\.mp4|$))", "/vid/", 2),
+					capture(r"https://v\.redd\.it/(.+)/(HLSPlaylist\.m3u8.*)$", "/hls/", 2)
+				),
+				"i.redd.it" => capture(r"https://i\.redd\.it/(.*)", "/img/", 1),
+				"a.thumbs.redditmedia.com" => capture(r"https://a\.thumbs\.redditmedia\.com/(.*)", "/thumb/a/", 1),
+				"b.thumbs.redditmedia.com" => capture(r"https://b\.thumbs\.redditmedia\.com/(.*)", "/thumb/b/", 1),
+				"emoji.redditmedia.com" => capture(r"https://emoji\.redditmedia\.com/(.*)/(.*)", "/emoji/", 2),
+				"preview.redd.it" => capture(r"https://preview\.redd\.it/(.*)", "/preview/pre/", 1),
+				"external-preview.redd.it" => capture(r"https://external\-preview\.redd\.it/(.*)", "/preview/external-pre/", 1),
+				"styles.redditmedia.com" => capture(r"https://styles\.redditmedia\.com/(.*)", "/style/", 1),
+				"www.redditstatic.com" => capture(r"https://www\.redditstatic\.com/(.*)", "/static/", 1),
+				_ => String::new(),
+			}
+		})
 	}
 }
 
 // Rewrite Reddit links to Libreddit in body of text
 pub fn rewrite_urls(input_text: &str) -> String {
-	let text1 = match Regex::new(r#"href="(https|http|)://(www.|old.|np.|amp.|)(reddit).(com)/"#) {
-		Ok(re) => re.replace_all(input_text, r#"href="/"#).to_string(),
-		Err(_) => String::new(),
-	};
+	let text1 = Regex::new(r#"href="(https|http|)://(www\.|old\.|np\.|amp\.|)(reddit\.com|redd\.it)/"#).map_or(String::new(), |re| re.replace_all(input_text, r#"href="/"#).to_string());
 
 	// Rewrite external media previews to Libreddit
-	match Regex::new(r"https://external-preview\.redd\.it(.*)[^?]") {
-		Ok(re) => {
-			if re.is_match(&text1) {
-				re.replace_all(&text1, format_url(re.find(&text1).map(|x| x.as_str()).unwrap_or_default())).to_string()
-			} else {
-				text1
-			}
+	Regex::new(r"https://external-preview\.redd\.it(.*)[^?]").map_or(String::new(), |re| {
+		if re.is_match(&text1) {
+			re.replace_all(&text1, format_url(re.find(&text1).map(|x| x.as_str()).unwrap_or_default())).to_string()
+		} else {
+			text1
 		}
-		Err(_) => String::new(),
-	}
+	})
 }
 
 // Append `m` and `k` for millions and thousands respectively
@@ -575,27 +568,17 @@ pub fn val(j: &Value, k: &str) -> String {
 	j["data"][k].as_str().unwrap_or_default().to_string()
 }
 
+// Escape < and > to accurately render HTML
 #[macro_export]
 macro_rules! esc {
 	($f:expr) => {
-		$f.replace('<', "&lt;").replace('>', "&gt;")
+		$f.replace('&', "&amp;").replace('<', "&lt;").replace('>', "&gt;")
 	};
 	($j:expr, $k:expr) => {
 		$j["data"][$k].as_str().unwrap_or_default().to_string().replace('<', "&lt;").replace('>', "&gt;")
 	};
 }
 
-// Escape < and > to accurately render HTML
-// pub fn esc(j: &Value, k: &str) -> String {
-// 	val(j,k)
-// 		// .replace('&', "&amp;")
-// 		.replace('<', "&lt;")
-// 		.replace('>', "&gt;")
-// 		// .replace('"', "&quot;")
-// 		// .replace('\'', "&#x27;")
-// 		// .replace('/', "&#x2f;")
-// }
-
 //
 // NETWORKING
 //
